import subprocess
from subprocess import PIPE

def checkVersion():
    cp = subprocess.run(["i2cdetect", "-y", "1"], stdout=PIPE)
    stdoutstr = str(cp.stdout)
    if "1e" in stdoutstr:
        return "4"
    if "1d" in stdoutstr:
        return "3"
    return "unknown"


from distutils.core import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='sagan',
    version='3.2.3',
    packages=['sagan'],
    install_requires=["smbus-cffi", "RPIO"],
    url='',
    license='',
    author='T A H Smith, A W Collins, Jeff Trotman',
    author_email='jtrotman@dreamup.org',
    description='Python library for interfacing with sagan board',
    long_description=long_description,
    long_description_content_type="text/markdown",
)



import os
import sys
import json

_FIFO = open(os.environ.get('TELEMETRY', '/dev/null'), 'w')


class Telemetry:
    @staticmethod
    def update(prefix: str, data: str):
        try:
            _FIFO.write("{}:{}\n".format(prefix[0:3], json.dumps(data)))
            _FIFO.flush()
        except BaseException as err:
            print("Telemetry.update: {}".format(err), file=sys.stderr)
            return False
        return True



import smbus
import time
import os
from .board import checkVersion
from .baro import Barometer
from .temperature import TemperatureSensor
from .imu import Accelerometer3, Accelerometer4, Magnetometer3, Magnetometer4, Gyroscope
from .rgb_ir import RgbIrSensor
from .uva import UvaSensor
from .rtc import RealTimeClock
from .leds import Leds
from .arducam import Camera

boardVersion = checkVersion()

bus = smbus.SMBus(1)
barometer = Barometer(bus, 0x76)
bottom_thermometer = TemperatureSensor(bus, 0x48)
top_thermometer = TemperatureSensor(bus, 0x49)

if boardVersion == "4":
    accelerometer = Accelerometer4(bus, 0x6B)
    magnetometer = Magnetometer4(bus, 0x1E)
    gyroscope = Gyroscope(bus, 0x6B)
else:
    accelerometer = Accelerometer3(bus, 0x1D)
    magnetometer = Magnetometer3(bus, 0x1D)
    gyroscope = Gyroscope(bus, 0x6b)

rgb_ir_sensor = RgbIrSensor(bus, 0x52)
uva_sensor = UvaSensor(bus, 0x38)
real_time_clock = RealTimeClock(bus, 0x51)

if boardVersion == "4":
    sensors = [
        barometer,
        bottom_thermometer,
        top_thermometer,
        accelerometer,
        magnetometer,
        rgb_ir_sensor,
        uva_sensor,
        real_time_clock
    ]
else:
    sensors = [
        barometer,
        bottom_thermometer,
        top_thermometer,
        accelerometer,
        gyroscope,
        rgb_ir_sensor,
        uva_sensor,
        real_time_clock
    ]


for sensor in sensors:
    sensor.configure({})

if boardVersion == "4":
    # gyroscope fails self-test but still works
    # skip self-test but still needs to be configured
    gyroscope.configure({})

for sensor in sensors:
    assert sensor.self_test(), 'Failed to initialise sensor {}'.format(repr(sensor))

leds = Leds()
camera = Camera()

def test():
    print("RUNNING TEST...")
    try:

        print(barometer.measure())
        print(bottom_thermometer.measure())
        print(top_thermometer.measure())
        print(accelerometer.measure())
        print(rgb_ir_sensor.measure())
        print(uva_sensor.measure())
        print(real_time_clock.measure())
        leds.set_blue("off")
        leds.set_green("off")
        leds.set_red("off")
        leds.set_led1("off")
        leds.set_led2("off")
        time.sleep(0.25)
        leds.set_led1("on")
        time.sleep(0.25)
        leds.set_led1("off")
        leds.set_led2("on")
        time.sleep(0.25)
        leds.set_led2("off")
        leds.set_red("on")
        time.sleep(0.25)
        leds.set_red("off")
        leds.set_green("on")
        time.sleep(0.25)
        leds.set_green("off")
        leds.set_blue("on")
        time.sleep(0.25)
        leds.set_blue("off")
    except:
        print("ERROR")
        return
    print("PASS")

__all__ = (
    'barometer',
    'bottom_thermometer',
    'top_thermometer',
    'accelerometer',
    'gyroscope',
    'magnetometer',
    'rgb_ir_sensor',
    'uva_sensor',
    'real_time_clock',
    'leds',
    'camera',
    'test'
)






